@@ -36,8 +36,8 @@ class ProductVariantSchema(Schema):
 
     id = fields.Int()
     price = fields.Integer()
-    stocks = RelatedResourceLinkField(schema='livestyled.schemas.product.ProductVariantStockSchema', many=True,
-                                      missing=[], microservice_aware=True)
+    stocks = RelatedResourceField(schema='livestyled.schemas.product.ProductVariantStockSchema', many=True,
+                                  microservice_aware=True)
     product = RelatedResourceLinkField(schema='livestyled.schemas.product.ProductSchema', microservice_aware=True)
     external_id = fields.String(missing=None, data_key='externalId')
     translations = fields.Nested(ProductVariantTranslationSchema, many=True, missing=None)
@@ -125,6 +125,7 @@ class ProductModifierItemSchema(Schema):
     additional_price = fields.Integer(data_key='additionalPrice')
     translations = fields.Nested(ProductModifierItemTranslationsSchema, many=True, missing=[])
     modifier_list = RelatedResourceLinkField('livestyled.schemas.product.ProductModifierListSchema', data_key='modifierList', microservice_aware=True)
+    status = fields.String(missing=None)
 
 
 class ProductModifierListTranslationsSchema(Schema):
